@@ -579,7 +579,8 @@ any other non-digit terminates the character code and is then used as input."))
 		 (setq char (aref translated 0)))))
       (cond ((null char))
 	    ((not (characterp char))
-	     (setq unread-command-events (list char)
+	     ;; XEmacs change; event instead of char. 
+	     (setq unread-command-events (list event)
 		   done t))
 ; 	    ((/= (logand char ?\M-\^@) 0)
 ; 	     ;; Turn a meta-character into a character with the 0200 bit set.
@@ -598,7 +599,8 @@ any other non-digit terminates the character code and is then used as input."))
 	    ((and (not first) (eq char ?\C-m))
 	     (setq done t))
 	    ((not first)
-	     (setq unread-command-events (list char)
+	     ;; XEmacs change; event instead of char. 
+	     (setq unread-command-events (list event)
 		   done t))
 	    (t (setq code (char-to-int char)
 		     done t)))
