@@ -119,6 +119,7 @@ buffer appears in it currently)."
 
 (defstruct window-configuration
   frame
+  frame-top frame-left
   frame-pixel-width frame-pixel-height
   current-buffer
   minibuffer-pixel-height
@@ -135,6 +136,10 @@ are identical."
 	      (window-configuration-frame-pixel-width conf-2))
 	   (= (window-configuration-frame-pixel-height conf-1)
 	      (window-configuration-frame-pixel-height conf-2))
+	   (equal (window-configuration-frame-top conf-1)
+		  (window-configuration-frame-top conf-2))
+	   (equal (window-configuration-frame-left conf-1)
+		  (window-configuration-frame-left conf-2))
 	   (eq (window-configuration-current-buffer conf-1)
 	       (window-configuration-current-buffer conf-2))
 	   (saved-window-equal (window-configuration-saved-root-window conf-1)
@@ -213,6 +218,8 @@ its value is -not- saved."
 	      
     (make-window-configuration
      :frame frame
+     :frame-top (frame-property frame 'top)
+     :frame-left (frame-property frame 'left)
      :frame-pixel-width (frame-pixel-width frame)
      :frame-pixel-height (frame-pixel-height frame)
      :current-buffer (current-buffer)
@@ -285,6 +292,15 @@ by `current-window-configuration'."
   (frame-reduce-to-one-window frame)
   (set-window-configuration-frame-size configuration)
 
+  ; avoid setting these if they're already up-to-date
+  ; This also avoids potential inaccuracies in these settings --Mike
+  (let ((left (window-configuration-frame-left configuration))
+	(top (window-configuration-frame-top configuration)))
+    (if (not (equal left (frame-property frame 'left)))
+	(set-frame-property frame 'left left))
+    (if (not (equal top (frame-property frame 'top)))
+	(set-frame-property frame 'top top))) 
+
   ;; these may have changed because of the delete
   (let ((root-window (frame-root-window frame)))
     (enlarge-window-pixels 
