@@ -28,11 +28,7 @@ xemacs-patches.
 */
 struct Lisp_PGconn
 {
-#ifdef MC_ALLOC
-  struct lrecord_header header;
-#else /* not MC_ALLOC */
-  struct lcrecord_header header;
-#endif /* not MC_ALLOC */
+  struct LCRECORD_HEADER header;
   PGconn *pgconn;
 };
 typedef struct Lisp_PGconn Lisp_PGconn;
@@ -52,11 +48,7 @@ DECLARE_LRECORD (pgconn, Lisp_PGconn);
 */
 struct Lisp_PGresult
 {
-#ifdef MC_ALLOC
-  struct lrecord_header header;
-#else /* not MC_ALLOC */
-  struct lcrecord_header header;
-#endif /* not MC_ALLOC */
+  struct LCRECORD_HEADER header;
   PGresult *pgresult;
 };
 typedef struct Lisp_PGresult Lisp_PGresult;
