@@ -46,15 +46,8 @@ NOTE-END */
 #define hp9000s300
 #endif
 
-/* Define CANNOT_DUMP on machines where unexec does not work.
-   Then the function dump-emacs will not be defined
-   and temacs will do (load "loadup") automatically unless told otherwise.  */
-
-/* #define CANNOT_DUMP */
-
-/* XEmacs: Richard Cognot <cognot@ensg.u-nancy.fr> says we need this for
-   HPUX; but eeide@asylum.cs.utah.edu (Eric Eide) says it loses on BSD. */
-#ifndef BSD
+/* Let the OS header file determine this if not HPUX. */
+#ifdef HPUX
 # define UNEXEC "unexhp9k3.o"
 #endif
 
@@ -71,8 +64,6 @@ NOTE-END */
 
 #define CRT0_DUMMIES		bogus_a6,
 
-#define HAVE_ALLOCA
-
 #ifndef __GNUC__
 #define LIBS_DEBUG		/* don't have -lg that works */
 #define C_DEBUG_SWITCH		/* don't support -g */
@@ -101,10 +92,6 @@ NOTE-END */
 
 #define LOAD_AVE_CVT(x) ((int) ((x) * 100.0))
 
-#ifdef __GNUC__
-#define HAVE_ALLOCA
-#endif
-
 /* This library is needed with -g, on the 200/300 only.  */
 
 #if !defined(__GNUC__) || defined(__HPUX_ASM__)
