@@ -28,11 +28,7 @@ Boston, MA 02111-1307, USA.  */
 
 typedef struct Lisp_Opaque
 {
-#ifdef MC_ALLOC
-  struct lrecord_header header;
-#else /* MC_ALLOC */
-  struct lcrecord_header header;
-#endif /* MC_ALLOC */
+  struct LCRECORD_HEADER header;
   Bytecount size;
   max_align_t data[1];
 } Lisp_Opaque;
@@ -58,11 +54,7 @@ Lisp_Object make_opaque (const void *data, Bytecount size);
 
 typedef struct Lisp_Opaque_Ptr
 {
-#ifdef MC_ALLOC
-  struct lrecord_header header;
-#else /* MC_ALLOC */
-  struct lcrecord_header header;
-#endif /* MC_ALLOC */
+  struct LCRECORD_HEADER header;
   void *ptr;
 } Lisp_Opaque_Ptr;
 
