@@ -27,11 +27,7 @@ Boston, MA 02111-1307, USA.  */
 
 struct scrollbar_instance
 {
-#ifdef MC_ALLOC
-  struct lrecord_header header;
-#else /* MC_ALLOC */
-  struct lcrecord_header header;
-#endif /* MC_ALLOC */
+  struct LCRECORD_HEADER header;
 
   /* Used by the frame caches. */
   struct scrollbar_instance *next;
