@@ -479,7 +479,7 @@ Test C interface to hash tables.
 
 
 
-#ifdef MC_ALLOC
+#ifdef NEW_GC
 #define TESTS_DEFSUBR(Fname) do {		\
   DEFSUBR_MC_ALLOC (Fname);			\
   defsubr (S##Fname);				\
@@ -487,14 +487,14 @@ Test C interface to hash tables.
     Fcons (intern (subr_name (S##Fname)),	\
 	   Vtest_function_list);		\
 } while (0)
-#else /* not MC_ALLOC */
+#else /* not NEW_GC */
 #define TESTS_DEFSUBR(Fname) do {		\
   DEFSUBR (Fname);				\
   Vtest_function_list =				\
     Fcons (intern (subr_name (&S##Fname)),	\
 	   Vtest_function_list);		\
 } while (0)
-#endif /* not MC_ALLOC */
+#endif /* not NEW_GC */
 
 void
 syms_of_tests (void)
