@@ -23,9 +23,18 @@ Boston, MA 02111-1307, USA.  */
 /* PrimitiveP.h doesn't exist in old versions of Motif; the stuff is
    in XmP.h instead */
 
-#include <Xm/Xm.h>	/* to get XmVersion */
+#ifndef INCLUDED_xmprimitivep_h_
+#define INCLUDED_xmprimitivep_h_
+
+#include "xmotif.h"	/* to get XmVersion */
+# define time time_
+# define message message_
 #if (XmVersion >= 1002)
 # include <Xm/PrimitiveP.h>
 #else
 # include <Xm/XmP.h>
 #endif
+# undef message
+# undef time
+
+#endif /* INCLUDED_xmprimitivep_h_ */
