@@ -2,11 +2,11 @@
 emacs_is_beta=t
 emacs_major_version=21
 emacs_minor_version=5
-emacs_beta_version=25
-xemacs_codename="eggplant"
+emacs_beta_version=26
+xemacs_codename="endive"
 emacs_kit_version=
 infodock_major_version=4
 infodock_minor_version=0
 infodock_build_version=8
 xemacs_extra_name=""
-xemacs_release_date="2006-02-26"
+xemacs_release_date="2006-04-01"
